==> subject-area-api-1.0-sources.jar: org/odpi/openmetadata/accessservices/subjectarea/responses/OMASExceptionToResponse.java <==
/* SPDX-License-Identifier: Apache-2.0 */
/* Copyright Contributors to the ODPi Egeria project. */
package org.odpi.openmetadata.accessservices.subjectarea.responses;

import org.odpi.openmetadata.accessservices.subjectarea.ffdc.exceptions.*;

public class OMASExceptionToResponse {

    public static SubjectAreaOMASAPIResponse convertInvalidParameterException(InvalidParameterException e) {
        InvalidParameterExceptionResponse response = new InvalidParameterExceptionResponse(e);
        return response;

    }
    public static SubjectAreaOMASAPIResponse convertUserNotAuthorizedException(UserNotAuthorizedException e) {
        UserNotAuthorizedExceptionResponse response = new UserNotAuthorizedExceptionResponse(e);
        return response;
    }

    public static SubjectAreaOMASAPIResponse convertUnrecognizedGUIDException(UnrecognizedGUIDException e) {
        UnrecognizedGUIDExceptionResponse response = new  UnrecognizedGUIDExceptionResponse(e);
        return response;
    }

    public static SubjectAreaOMASAPIResponse convertStatusNotSupportedException(StatusNotSupportedException e) {
        StatusNotsupportedExceptionResponse response = new StatusNotsupportedExceptionResponse(e);
        return response;
    }

    public static SubjectAreaOMASAPIResponse convertFunctionNotSupportedException(FunctionNotSupportedException e) {
        FunctionNotSupportedExceptionResponse response = new   FunctionNotSupportedExceptionResponse(e);
        return response;
    }

    public static SubjectAreaOMASAPIResponse convertStatusNotsupportedException(StatusNotSupportedException e) {
        StatusNotsupportedExceptionResponse response= new StatusNotsupportedExceptionResponse(e);
        return response;
    }

    public static SubjectAreaOMASAPIResponse convertClassificationException(ClassificationException e) {
        ClassificationExceptionResponse response = new ClassificationExceptionResponse(e);
        return response;
    }

    public static SubjectAreaOMASAPIResponse convertGUIDNotPurgedException(GUIDNotPurgedException e) {
        GUIDNotPurgedExceptionResponse response = new GUIDNotPurgedExceptionResponse(e);
        return response;
    }
    public static SubjectAreaOMASAPIResponse convertGUIDNotDeletedException(GUIDNotDeletedException e)
    {
        GUIDNotDeletedExceptionResponse response = new GUIDNotDeletedExceptionResponse(e);
        return response;
    }

    public static SubjectAreaOMASAPIResponse convertEntityNotDeletedException(EntityNotDeletedException e) {
        EntityNotDeletedExceptionResponse response = new EntityNotDeletedExceptionResponse(e);
        return response;
    }

    public static SubjectAreaOMASAPIResponse convertMetadataServerUncontactableException(MetadataServerUncontactableException e) {
        MetadataServerUncontactableExceptionResponse response = new MetadataServerUncontactableExceptionResponse(e);
        return response;
    }

    public static SubjectAreaOMASAPIResponse convertRelationshipNotDeletedException(RelationshipNotDeletedException e)
    {
        RelationshipNotDeletedExceptionResponse response = new RelationshipNotDeletedExceptionResponse(e);
        return response;
    }

    public static SubjectAreaOMASAPIResponse convertUnrecognizedNameException(UnrecognizedNameException e)
    {
        UnrecognizedNameExceptionResponse response = new UnrecognizedNameExceptionResponse(e);
        return response;
    }


}

==> subject-area-api-1.2-sources.jar: org/odpi/openmetadata/accessservices/subjectarea/responses/OMASExceptionToResponse.java <==
/* SPDX-License-Identifier: Apache-2.0 */
/* Copyright Contributors to the ODPi Egeria project. */
package org.odpi.openmetadata.accessservices.subjectarea.responses;

import org.odpi.openmetadata.accessservices.subjectarea.ffdc.exceptions.*;

public class OMASExceptionToResponse {

    public static SubjectAreaOMASAPIResponse convertInvalidParameterException(InvalidParameterException e) {
        return new InvalidParameterExceptionResponse(e);
    }
    public static SubjectAreaOMASAPIResponse convertUserNotAuthorizedException(UserNotAuthorizedException e) {
       return  new UserNotAuthorizedExceptionResponse(e);

    }

    public static SubjectAreaOMASAPIResponse convertUnrecognizedGUIDException(UnrecognizedGUIDException e) {
       return new UnrecognizedGUIDExceptionResponse(e);
    }

    public static SubjectAreaOMASAPIResponse convertStatusNotSupportedException(StatusNotSupportedException e) {
        return new StatusNotsupportedExceptionResponse(e);
    }

    public static SubjectAreaOMASAPIResponse convertFunctionNotSupportedException(FunctionNotSupportedException e) {
       return new  FunctionNotSupportedExceptionResponse(e);
    }

    public static SubjectAreaOMASAPIResponse convertStatusNotsupportedException(StatusNotSupportedException e) {
       return new StatusNotsupportedExceptionResponse(e);
    }

    public static SubjectAreaOMASAPIResponse convertClassificationException(ClassificationException e) {
       return new ClassificationExceptionResponse(e);
    }

    public static SubjectAreaOMASAPIResponse convertGUIDNotPurgedException(GUIDNotPurgedException e) {
       return new GUIDNotPurgedExceptionResponse(e);
    }

    public static SubjectAreaOMASAPIResponse convertGUIDNotDeletedException(GUIDNotDeletedException e)
    {
       return new GUIDNotDeletedExceptionResponse(e);
    }

    public static SubjectAreaOMASAPIResponse convertEntityNotDeletedException(EntityNotDeletedException e) {
        return new EntityNotDeletedExceptionResponse(e);
    }

    public static SubjectAreaOMASAPIResponse convertMetadataServerUncontactableException(MetadataServerUncontactableException e) {
       return new MetadataServerUncontactableExceptionResponse(e);
    }

    public static SubjectAreaOMASAPIResponse convertRelationshipNotDeletedException(RelationshipNotDeletedException e)
    {
      return new RelationshipNotDeletedExceptionResponse(e);
    }

    public static SubjectAreaOMASAPIResponse convertUnrecognizedNameException(UnrecognizedNameException e)
    {
       return new UnrecognizedNameExceptionResponse(e);
    }
}
